BrowserID Page Object Model
===========================

Selenium compatible page object model for
`Mozilla Persona <https://login.persona.org/>`_ (previously known as BrowserID).

.. image:: https://img.shields.io/badge/license-MPL%202.0-blue.svg
   :target: https://github.com/mozilla/bidpom/blob/master/LICENSE
   :alt: License
.. image:: https://img.shields.io/pypi/v/bidpom.svg
   :target: https://pypi.python.org/pypi/bidpom/
   :alt: PyPI
.. image:: https://img.shields.io/travis/mozilla/bidpom.svg
   :target: https://travis-ci.org/mozilla/bidpom/
   :alt: Travis
.. image:: https://img.shields.io/github/issues-raw/mozilla/bidpom.svg
   :target: https://github.com/mozilla/bidpom/issues
   :alt: Issues
.. image:: https://img.shields.io/requires/github/mozilla/bidpom.svg
   :target: https://requires.io/github/mozilla/bidpom/requirements/?branch=master
   :alt: Requirements

Resources
---------

- `Documentation <https://github.com/mozilla/bidpom/wiki>`_
- `Issue Tracker <https://github.com/mozilla/bidpom/issues>`_
- `Code <http://github.com/mozilla/bidpom/>`_
